[][src]Enum twitter_stream::error::Error

pub enum Error {
    Gzip(Error),
    Http(StatusCode),
    Hyper(HyperError),
    TimedOut,
    Utf8(Utf8Error),
    Custom(Box<dyn Error + Send + Sync>),
}

An error occurred while trying to connect to a Stream.

Variants

An error occured while decoding gzip stream from the server.

An HTTP error from the Stream.

An error from the hyper crate.

The stream has timed out.

Twitter returned a non-UTF-8 string.

User-defined error.

Methods

impl Error
[src]