Enum twitter_stream::types::WithheldScope
[−]
[src]
pub enum WithheldScope {
Status,
User,
Custom(String),
}Represents the withheld_scope field in Tweet and User.
Variants
StatusUserCustom(String)Trait Implementations
impl Clone for WithheldScope[src]
fn clone(&self) -> WithheldScope
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl Debug for WithheldScope[src]
impl<'x> Deserialize<'x> for WithheldScope[src]
fn deserialize<D: Deserializer<'x>>(d: D) -> Result<Self, D::Error>
Deserialize this value from the given Serde deserializer. Read more
impl AsRef<str> for WithheldScope[src]
impl PartialEq for WithheldScope[src]
fn eq(&self, other: &WithheldScope) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Hash for WithheldScope[src]
fn hash<H: Hasher>(&self, state: &mut H)
Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0
H: Hasher,
Feeds a slice of this type into the given [Hasher]. Read more