An error occurred while trying to connect to a Stream.
An error occured while decoding gzip stream from the server.
An HTTP error from the Stream.
An error from the hyper crate.
The stream has timed out.
Twitter returned a non-UTF-8 string.
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
Deprecating in 1.33.0
: replaced by Error::source, which can support downcasting
The lower-level cause of this error, if any. Read more
The lower-level source of this error, if any. Read more
Converts the given value to a String. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static